@@ -81,7 +81,7 @@ class Client(object):
         else:
             print("In order to use this SDK, you must provide a Quickbase user token.")
 
-    def request(self, action, database, data):
+    def request(self, action, database, data, return_fields=None):
         """Do a QuickBase request and return the parsed JSON response. Raises appropriate
         Error subclass on HTTP, response or QuickBase error. If fields list given,
         return dict with all fields in list (raises ResponseError if any not present),
@@ -91,16 +91,27 @@ class Client(object):
         if action == "query":
             url = "https://api.quickbase.com/v1/records/query"
 
+            json = {
+                "to": database,
+                "data": data,
+            }
+
         if action == "add" or action == "edit":
             url = "https://api.quickbase.com/v1/records"
 
+            json = {
+                "to": database,
+                "data": data,
+                'fieldsToReturn': return_fields if return_fields else [3]
+            }
+
         tries = 0
         while True:
             try:
 
                 response = requests.post(
-                    url, json={"to": database,
-                               "data": data}, headers=self.headers, timeout=None)
+                    url, json=json,
+                    headers=self.headers, timeout=None)
 
                 break
             except ConnectionError as e:
@@ -415,7 +426,7 @@ class Client(object):
 
         return response
 
-    def add_record(self, fields, database=None, uploads=None, safemode=False):
+    def add_record(self, fields, database=None, uploads=None, safemode=False, return_fields=None):
         """
         Adds record(s) to quickbase database.
         :param fields: key, value dict, i.e. {'19': 'value'}
@@ -451,7 +462,7 @@ class Client(object):
 
         # upload record via request, store response to return
         response = self.request(
-            action='add', database=database or self.database, data=[record])
+            action='add', database=database or self.database, data=[record], return_fields=return_fields)
 
         # convert the response to a json object
         response = response.json()
@@ -477,7 +488,10 @@ class Client(object):
                     code=-4)
 
             # return the RID of the created record
-            return response["metadata"]["createdRecordIds"][0]
+            if return_fields:
+                return self.denest(response['data'])[0]
+            else:
+                return response["metadata"]["createdRecordIds"][0]
 
         # catchall error
         except Exception as e:
@@ -529,7 +543,6 @@ class Client(object):
         }
         url = 'https://api.quickbase.com/v1/records'
 
-        print('performing call')
         response = requests.delete(url, headers=headers, json=body)
         return response
 
@@ -772,7 +785,7 @@ class Client(object):
 
         return response
 
-    def edit_record(self, rid=None, key=None, fields=None, database=None, uploads=None):
+    def edit_record(self, rid=None, key=None, fields=None, database=None, uploads=None, return_fields=None):
         """
         Edit a record by providing rid of record, and other necessary data
         If both a key and a rid are provided, key will be prioritized
@@ -814,7 +827,7 @@ class Client(object):
 
             # upload record via request, store response to return
             response = self.request(
-                action='edit', database=database or self.database, data=[record])
+                action='edit', database=database or self.database, data=[record], return_fields=return_fields)
 
             # convert the response to a json object
             response = response.json()
@@ -834,10 +847,14 @@ class Client(object):
                     # should only be one
 
                 # return the RID of the created record
-                try:
-                    return response["metadata"]["updatedRecordIds"][0]
-                except IndexError:
-                    return response["metadata"]["unchangedRecordIds"][0]
+                if return_fields:
+                    return self.denest(response['data'])[0]
+                else:
+                
+                    try:
+                        return response["metadata"]["updatedRecordIds"][0]
+                    except IndexError:
+                        return response["metadata"]["unchangedRecordIds"][0]
 
             # catchall error
             except Exception as e:
