@@ -1,5 +1,8 @@
 import time
-from . import json_quickbase, xml_quickbase
+try:
+    from . import json_quickbase, xml_quickbase
+except ImportError:
+    import json_quickbase, xml_quickbase
 from typing import Union, Dict
 import os
 import getpass
