@@ -7,18 +7,16 @@ def main():
     })
     data = [
         {
-            '3': 113,
             '6': '4'
         },
-        {
-            '3': '112',
-            '6': ''
-        }
     ]
+    record = {
+        '6': 3
+    }
 
 
 
-    response = client.do_query(database='bnj3ts22e', query='{3.GT.50}', columns=[3])
+    response = client.delete_record(database='bnj3ts22e', record=116)
     print(response)
 
 
